AppPadding class

Constructors

AppPadding()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

p0 → const double
p2 → const double
p4 → const double
p6 → const double
p8 → const double
p10 → const double
p12 → const double
p14 → const double
p16 → const double
p18 → const double
p20 → const double
p24 → const double
p28 → const double
p30 → const double
p36 → const double
p40 → const double
p60 → const double
p100 → const double