DeviceStatusModel class
Point-in-time snapshot of the device's OS/kernel and memory stats, as
returned by Utility.getDeviceStatus.
Constructors
- DeviceStatusModel({required String kernelArchitecture, required int kernelBitness, required String kernelName, required String kernelVersion, required String operatingSystemName, required String operatingSystemVersion, required String userDirectory, required String userId, required String userName, required int userSpaceBitness, required int numberOfProcessors, required int totalPhysicalMemory, required int freePhysicalMemory, required int totalVirtualMemory, required int freeVirtualMemory, required int virtualMemorySize})
-
const
Properties
- freePhysicalMemory → int
-
In megabytes.
final
- freeVirtualMemory → int
-
In megabytes.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kernelArchitecture → String
-
final
- kernelBitness → int
-
final
- kernelName → String
-
final
- kernelVersion → String
-
final
- numberOfProcessors → int
-
final
- operatingSystemName → String
-
final
- operatingSystemVersion → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalPhysicalMemory → int
-
In megabytes.
final
- totalVirtualMemory → int
-
In megabytes.
final
- userDirectory → String
-
final
- userId → String
-
final
- userName → String
-
final
- userSpaceBitness → int
-
final
- virtualMemorySize → int
-
In megabytes.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited