PickerModel class

Constructors

PickerModel({String? id, String? code, String? name, String? statusCode, String? iconSrc})
PickerModel.fromJson(Map<String, dynamic> parsedJson)
factory

Properties

code String?
final
hashCode int
The hash code for this object.
no setterinherited
iconSrc String?
final
id String?
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonRequest() Map<String, String?>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited