TableHeaderModel class

Constructors

TableHeaderModel({required String field, String? fieldColor, int? backgroundColor, required String title, String format = TableViewTypeValue.text, double width = 0, double fontSize = 12.0})

Properties

backgroundColor int?
getter/setter pair
field String
getter/setter pair
fieldColor String?
getter/setter pair
fontSize double
getter/setter pair
format String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
getter/setter pair
width double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited