NullableStringExtensions<E> extension

Extension methods for a nullable String.

on

Properties

isNotNullNorEmpty bool

Available on String?, provided by the NullableStringExtensions extension

Returns true if this string is not null and not empty.
no setter
isNullOrEmpty bool

Available on String?, provided by the NullableStringExtensions extension

Returns true if this string is null or empty.
no setter