isNotNullNorEmpty property
bool
get
isNotNullNorEmpty
Returns true if this string is not null and not empty.
Implementation
bool get isNotNullNorEmpty {
return this?.isNotEmpty ?? false;
}
Returns true if this string is not null and not empty.
bool get isNotNullNorEmpty {
return this?.isNotEmpty ?? false;
}