isNullOrEmpty property
bool
get
isNullOrEmpty
Returns true if this string is null or empty.
Implementation
bool get isNullOrEmpty {
return this?.isEmpty ?? true;
}
Returns true if this string is null or empty.
bool get isNullOrEmpty {
return this?.isEmpty ?? true;
}