KatUtils class
Properties
hashCode
→ int
The hash code for this object.
no setter inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited
Static Properties
addTextWatermarkCentered
→ Uint8List Function(Uint8List imgBytes , String watermarkText , int dstX , int dstY , {Color color = Colors.black , BitmapFont? font , bool rightJustify = false })
final
capitalizeFirstLetter
→ String Function(String text )
final
chooseDate
→ Future <DateTime ? > Function({required BuildContext context , DateTime ? firstDate , String ? initialDate })
final
chooseDateRange
→ Future <DateTimeRange <DateTime > ? > Function({required BuildContext context , DateTimeRange <DateTime > ? initialDateRange })
final
chooseDateTime
→ Future <DateTime ? > Function({required BuildContext context , String ? initialDate })
final
chooseTime
→ Future <DateTime ? > Function({required BuildContext context , required String date })
final
compressAndroidFile
→ Future <Uint8List ? > Function(String path , {KatCompressFormat format = KatCompressFormat.webp , int height = 1080 , int quality = 95 , int width = 1920 })
final
compressAndroidList
→ Future <Uint8List > Function(Uint8List image , {KatCompressFormat format = KatCompressFormat.webp , int height = 1080 , int quality = 95 , int width = 1920 })
final
compressAndroidStream
→ Future <Uint8List ? > Function(String assetName , {KatCompressFormat format = KatCompressFormat.webp , int height = 768 , int quality = 95 , int width = 1024 })
final
compressAndroidVideo
→ Future <Uint8List ? > Function(String path )
final
compressBytesAndroid
→ Future <Uint8List > Function(Uint8List image , {KatCompressFormat format = KatCompressFormat.webp , required int imageScaleSize , required int minimumHeight , required int minimumWidth })
final
convertFullAddress
→ String Function({String ? addressLine , String ? districtName , String ? provinceName , String ? wardName })
final
convertTextCurrencyToInt
→ int Function(String ? value )
final
dateNotTime
→ DateTime Function(DateTime date )
final
dateParseServerTime
→ String Function(String ? date , {String ? format })
final
dateWithCurrentTime
→ DateTime Function(DateTime date )
final
defaultLocaleName
↔ String
Fallback locale name for getLocaleName when the OS reports "und"
(undetermined). Override once at startup for the app's own default.
getter/setter pair
displayDistance
→ String ? Function(double ? distance )
final
downloadFile
→ Future <void > Function(Uint8List ? data , String ? fileName )
final
formatBytes
→ String Function(int bytes , int decimals )
final
formatDuration
→ String Function(Duration duration )
final
getAssetImageUint8List
→ Future <Uint8List > Function(String key )
final
getContentType
→ String Function(String text )
final
initialCalendarDate
→ DateTime Function(String ? strDate )
final
inputDecimalFormatter
→ List <TextInputFormatter > Function()
final
inputNumberFormatter
→ List <TextInputFormatter > Function()
final
isAtSameCurrentDate
→ bool Function(DateTime ? otherDate )
final
isBeforeCurrentDate
→ bool Function(String strDate , {int ? minutesAdd })
final
isBeforeDateVersion
→ bool Function(String firstDate , String secondDate )
final
isDateSecondBeforeFirst
→ bool Function(String ? dateFirst , String ? dateSecond )
final
isNowOrAfterCurrentDate
→ bool Function(String ? strDate )
final
lastDateOfMonth
→ DateTime Function()
final
lblDecimal
→ String Function(double ? value , {int ? digits , String ? symbol })
final
maxDatePicker
→ DateTime Function()
final
millisecondsBetween
→ int Function(DateTime from , DateTime to )
final
minDatePicker
→ DateTime Function(String ? strDate )
final
openDownloadFile
→ Future <void > Function(String ? fileName )
final
parseLocalTime
→ DateTime ? Function(String ? date )
final
pickFiles
→ Future <List <KatPlatformFile > > Function({bool allowMultiple = false , List <String > ? allowedExtensions , KatFileType type = KatFileType.any })
final
removeUnicode
→ String Function(String ? strData )
final
revertFullAddress
→ Tuple4 <String , String , String , String > Function(String ? fullAddress )
final
saveImageToGallery
→ Future <KatAssetEntity ? > Function(Uint8List value , String fileName )
final
shortText
→ String Function(String ? text , int length )
final
shortUserName
→ String Function(String text )
final
valCurrency
→ String Function(double ? value , {String ? locale , String ? symbol })
final
valDateTime
→ String Function(String ? date , {String ? format })
final
valDateTimeRange
→ String Function(List <String > ? dateTimeRange )
final
valDecimal
→ String Function(double ? value , {int ? digits , String ? locale })
final
valNumber
→ String Function(int ? value , {String ? locale })
final