initialAssets property
Assets already picked before this screen was shown, e.g. when resuming a previous selection.
Implementation
final List<KatAssetEntity> initialAssets;
Assets already picked before this screen was shown, e.g. when resuming a previous selection.
final List<KatAssetEntity> initialAssets;