controller property
Drives the toolbar and editor, and receives the image/link edits made through the custom toolbar buttons.
Implementation
final KatQuillEditorController controller;
Drives the toolbar and editor, and receives the image/link edits made through the custom toolbar buttons.
final KatQuillEditorController controller;