KatInputModel class

Bundles a text field's placeholder, initial value, controller, and change callback so they can be passed around as a single value.

Constructors

KatInputModel({required String placeholder, String? initValue, required ValueChanged<String> onTextChange, required TextEditingController controller})
const

Properties

controller TextEditingController
final
hashCode int
The hash code for this object.
no setterinherited
initValue String?
final
onTextChange ValueChanged<String>
final
placeholder String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited