KatTextField class

Inheritance

Constructors

KatTextField({Key? key, String? label, String? hintText, String? suffixText, String? initialValue, Icon? icon, Widget? suffixIcon, bool autovalidate = false, bool readOnly = false, bool isRequired = false, int? maxLines, int? maxLength, TextStyle? style, TextStyle? suffixStyle, TextAlign textAlign = TextAlign.start, TextEditingController? controller, TextInputType? keyboardType = TextInputType.text, InputDecoration? decoration, EdgeInsets scrollPadding = const EdgeInsets.all(20.0), List<TextInputFormatter>? inputFormatters, Function? onChanged, Function? validator, Function? onTap, Function? onFieldSubmitted})
const

Properties

autovalidate bool
final
controller TextEditingController?
final
decoration InputDecoration?
final
hashCode int
The hash code for this object.
no setterinherited
hintText String?
final
icon Icon?
final
initialValue String?
final
inputFormatters List<TextInputFormatter>?
final
isRequired bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType TextInputType?
final
label String?
final
maxLength int?
final
maxLines int?
final
onChanged Function?
final
onFieldSubmitted Function?
final
onTap Function?
final
readOnly bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollPadding EdgeInsets
final
style TextStyle?
final
suffixIcon Widget?
final
suffixStyle TextStyle?
final
suffixText String?
final
textAlign TextAlign
final
validator Function?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited