KatTooltip class

A tooltip with arbitrary content and an arrow pointing at its target, shown in an overlay above the rest of the app.

The target is either child itself (tapping it toggles the tooltip), or the widget at targetGlobalKey (for a tooltip triggered some other way - see KatTooltipState.toggle). Exactly one of the two must be given.

Tapping outside the tooltip while it's shown dismisses it. Set delay to show it automatically that long after this widget first builds.

Inheritance

Constructors

KatTooltip({Key? key, required Widget content, GlobalKey<State<StatefulWidget>>? targetGlobalKey, ThemeData? theme, Duration? delay, double tooltipMinimumHeight = AppSize.s220, Widget? child, KatTooltipPosition position = KatTooltipPosition.auto})
const

Properties

child Widget?
final
content Widget
final
delay Duration?
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
position KatTooltipPosition
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetGlobalKey GlobalKey<State<StatefulWidget>>?
final
theme ThemeData?
final
tooltipMinimumHeight double
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<KatTooltip>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited