widgets/popups/kat_auto_close_popup library

Functions

katAutoClosePopup<T>({required BuildContext context, required String title, required String message, Duration duration = const Duration(seconds: 1)}) Future<T?>
Shows a modal popup with title and message that closes itself after duration instead of waiting on a user action.