KatTreeView class

Inheritance

Constructors

KatTreeView({Key? key, required List<KatTreeNodeData>? data, void onTap(KatTreeNodeData node)?, void onCheck(bool checked, KatTreeNodeData node)?, void onLoad(KatTreeNodeData node)?, void onExpand(KatTreeNodeData node)?, void onCollapse(KatTreeNodeData node)?, void onAppend(KatTreeNodeData node, KatTreeNodeData? parent)?, void onRemove(KatTreeNodeData node, KatTreeNodeData? parent)?, void onAddParent()?, KatTreeNodeData append(KatTreeNodeData parent)?, Future<List<KatTreeNodeData>> load(KatTreeNodeData parent)?, bool lazy = false, double offsetLeft = 24.0, int? maxLines, bool showFilter = false, String filterPlaceholder = 'Search', bool showActions = false, bool showCheckBox = false, bool showRequired = false, bool contentTappable = false, Widget icon = const Icon(Icons.expand_more, size: 16.0), bool manageParentState = false})
const

Properties

append KatTreeNodeData Function(KatTreeNodeData parent)?
final
contentTappable bool
final
data List<KatTreeNodeData>?
final
filterPlaceholder String
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lazy bool
final
load Future<List<KatTreeNodeData>> Function(KatTreeNodeData parent)?
final
manageParentState bool
Desired behavior:
final
maxLines int?
final
offsetLeft double
final
onAddParent → void Function()?
final
onAppend → void Function(KatTreeNodeData node, KatTreeNodeData? parent)?
final
onCheck → void Function(bool checked, KatTreeNodeData node)?
final
onCollapse → void Function(KatTreeNodeData node)?
final
onExpand → void Function(KatTreeNodeData node)?
final
onLoad → void Function(KatTreeNodeData node)?
final
onRemove → void Function(KatTreeNodeData node, KatTreeNodeData? parent)?
final
onTap → void Function(KatTreeNodeData node)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showActions bool
final
showCheckBox bool
final
showFilter bool
final
showRequired bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<KatTreeView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited