widgets/controls/kat_editor library
Classes
- KatEditor
-
A rich-text editor row: an optional leading icon, an optional label
above the editor, a formatting toolbar, and the underlying
QuillHtmlEditor. - TextFieldEmbedImage
- A bottom-sheet form prompting for a URL - used by KatEditor's toolbar to collect the target for an embedded image or a link.