KatLoadingPopup class
A modal, non-dismissible loading popup showing a spinner and an optional message.
Usage:
KatLoadingPopup.show(context, text: 'Loading...');
// ... do work ...
KatLoadingPopup.hide(context);
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
hide(
BuildContext context) → void - Closes the loading popup previously opened with show.
-
show(
BuildContext context, {String text = '', bool barrierDismissible = false}) → Future< void> -
Shows the loading popup. Set
barrierDismissibletotrueto allow closing it by tapping outside.