KatTreeNode class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- KatTreeNode
Constructors
-
KatTreeNode({Key? key, required KatTreeNodeData data, required KatTreeNodeData? parent, State<
StatefulWidget> ? parentState, required double offsetLeft, int? maxLines, required bool showCheckBox, required bool showRequired, required bool showActions, required bool contentTappable, required Widget icon, required bool lazy, required Future<bool> load(KatTreeNodeData node), required void append(KatTreeNodeData node), required void remove(KatTreeNodeData node), required void onTap(KatTreeNodeData node), required void onCheck(bool checked, KatTreeNodeData node), required void onLoad(KatTreeNodeData node), required void onExpand(KatTreeNodeData node), required void onAppend(KatTreeNodeData node, KatTreeNodeData? parent), required void onRemove(KatTreeNodeData node, KatTreeNodeData? parent), required void onCollapse(KatTreeNodeData node)}) -
const
Properties
- append → void Function(KatTreeNodeData node)
-
final
- contentTappable → bool
-
final
- data → KatTreeNodeData
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lazy → bool
-
final
-
load
→ Future<
bool> Function(KatTreeNodeData node) -
final
- maxLines → int?
-
final
- offsetLeft → double
-
final
- onAppend → void Function(KatTreeNodeData node, KatTreeNodeData? parent)
-
final
- onCheck → void Function(bool checked, KatTreeNodeData node)
-
final
- onCollapse → void Function(KatTreeNodeData node)
-
final
- onExpand → void Function(KatTreeNodeData node)
-
final
- onLoad → void Function(KatTreeNodeData node)
-
final
- onRemove → void Function(KatTreeNodeData node, KatTreeNodeData? parent)
-
final
- onTap → void Function(KatTreeNodeData node)
-
final
- parent → KatTreeNodeData?
-
final
-
parentState
→ State<
StatefulWidget> ? -
final
- remove → void Function(KatTreeNodeData node)
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showActions → bool
-
final
- showCheckBox → bool
-
final
- showRequired → bool
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< KatTreeNode> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited